.. image:: https://badge.fury.io/py/sc-utilities.svg
    :target: https://badge.fury.io/py/sc-utilities
.. image:: https://img.shields.io/pypi/pyversions/sc-utilities
    :alt: PyPI - Python Version

A simple python utilities
========================================

This project provides some simple python utilities, such as logging, files and singleton.


Installation
------------

It is possible to install the tool with `pip`::

    pip install sc-utilities

Configuration
-------------

None

Dependencies
------------

None

Changes
-------

Version 0.0.1
    * Initial version

License
-------

The script is released under the MIT License.  The MIT License is registered
with and approved by the Open Source Initiative [1]_.

.. [1] https://opensource.org/licenses/MIT
